
[![Build Status](https://github.com/pcarolan/parkour/workflows/Tests/badge.svg)](https://github.com/pcarolan/parkour/actions?query=workflow%3ATests)

#  Parkour

Data replication utility

## Roadmap

+ [X] Connect to a Postgres database
+ [ ] Connect to a MySQL database
+ [X] Stream Data to a generator
+ [ ] Reflect schema from database
+ [ ] Load data and schema to apache arrow format
+ [ ] Save table as Parquet File on disk
+ [ ] Save table as Parquet File on s3
